g++ -o ./gammagen gammagen.cpp
./gammagen ../../src/lvfont/gammatbl.h
rm -f ./gammagen
